@@ -23,8 +23,38 @@
 ##' \code{idig_search_records} or \code{idig_search_media}, it would look like
 ##' this:
 ##' \preformatted{
-##' rq <- list("scientificname"=list("type"="exists"), "family"="asteraceae")
+##' rq <- list("scientificname"=list("type"="exists"), 
+##'            "family"="asteraceae"
+##'            )
 ##' }
+##' An example of a more complex JSON query with nested structures:
+##' \preformatted{
+##' {
+##'   "geopoint": {
+##'    "type": "geo_bounding_box",
+##'    "top_left": {
+##'      "lat": 19.23,
+##'      "lon": -130
+##'     },
+##'     "bottom_right": {
+##'       "lat": -45.1119,
+##'       "lon": 179.99999
+##'     }
+##'    }
+##'  }
+##' }
+##' 
+##' To rewrite this in R for use as the rq parameter, use nested calls to the 
+##' list() function:
+##'\preformatted{
+##' rq <- list(geopoint=list(
+##'                          type="geo_bounding_box", 
+##'                          top_left=list(lat=19.23, lon=-130), 
+##'                          bottom_right=list(lat=-45.1119, lon= 179.99999)
+##'                         )
+##'            )
+##' }
+##' 
 ##' See the Examples section below for more samples of simpler and more complex
 ##' queries. Please refer to the API documentation for the full functionality
 ##' availible in queries.
@@ -101,7 +131,8 @@ idig_search_records <- function(rq, fields=FALSE, max_items=100000, limit=0,
                      'stateprovince',
                      'geopoint',
                      'datecollected',
-                     'collector')
+                     'collector',
+                     'recordset')
 
   # Validate inputs
   if (!(inherits(rq, "list"))) { stop("rq is not a list") }
